<?php
    /**
     * ReduxFramework Tr Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "trconf";

    /*
     *
     * --> Action hook examples
     *
     */

    // If Redux is running as a plugin, this will remove the demo notice and links
    add_action( 'redux/loaded', 'tr_remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    add_filter('redux/options/' . $opt_name . '/compiler', 'tr_compiler_action', 10, 3);

    load_theme_textdomain(TR_THEMENAMEOPTIONS, get_template_directory().'/languages/');

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */


    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'disable_tracking' => true,
        'show_hints' => false,
        'dismiss' => false,
        'hint' => false,
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => false,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Options', TR_THEMENAMEOPTIONS ),
        'page_title'           => __( 'Options', TR_THEMENAMEOPTIONS ),
        // You will need to generate a Google API key to use this feature.
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => false,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        'page_type' => 'submenu',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        'footer_credit'     => '<a target="_blank" href="http://torothemes.com/">ToroThemes</a>',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'system_info'          => false,
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/torothemes',
        'title' => __( 'Follow us on Twitter', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-twitter'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = '';
    } else {
        $args['intro_text'] = '';
    }

    // Add content after the form.
    $args['footer_text'] = '';

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     *
     * ---> START SECTIONS
     *
     */

    Redux::setSection( $opt_name, array(
        'title' => __( 'General', TR_THEMENAMEOPTIONS ),
        'id'    => 'general',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-home',
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Basic', TR_THEMENAMEOPTIONS ),
        'id'         => 'basic',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            
            array(
                'id'       => 'email',
                'type'     => 'text',
                'title'    => __( 'Email', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Please enter a valid email.', TR_THEMENAMEOPTIONS ),
                'validate' => 'email',
                'msg'      => 'Error',
                'default'  => get_option('admin_email'),
            ),
            
            array(
                'id'       => 'feedburner',
                'type'     => 'text',
                'title'    => __( 'Feedburner', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Enter your user if you wish to have the newsletter footer. To disable leave the field empty.', TR_THEMENAMEOPTIONS ),
                'default'  => __('torothemes', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'      => 'posts_per_page',
                'type'    => 'spinner',
                'title'   => __( 'Posts per page', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of posts to display per page', TR_THEMENAMEOPTIONS ),
                'default' => '20',
                'min'     => '1',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'posts_per_related_posts',
                'type'    => 'spinner',
                'title'   => __( 'Number of posts in related (Posts)', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of posts related to display on posts. (0 to disable)', TR_THEMENAMEOPTIONS ),
                'default' => '5',
                'min'     => '0',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'posts_per_pornstars',
                'type'    => 'spinner',
                'title'   => __( 'Number of posts (Pornstars)', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of posts to display on pornstars. (0 to disable)', TR_THEMENAMEOPTIONS ),
                'default' => '5',
                'min'     => '0',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'posts_per_related_pornstars',
                'type'    => 'spinner',
                'title'   => __( 'Number of posts in related (Pornstars)', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of posts related to display on pornstars. (0 to disable)', TR_THEMENAMEOPTIONS ),
                'default' => '5',
                'min'     => '0',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'posts_per_pages',
                'type'    => 'spinner',
                'title'   => __( 'Number of posts on internal pages', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of posts to be displayed on the site pages. (Tags, search, category...)', TR_THEMENAMEOPTIONS ),
                'default' => '20',
                'min'     => '1',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'posts_per_blog',
                'type'    => 'spinner',
                'title'   => __( 'Number of posts on blog', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of posts to be displayed on the blog.', TR_THEMENAMEOPTIONS ),
                'default' => '10',
                'min'     => '1',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'categories_number',
                'type'    => 'spinner',
                'title'   => __( 'Number of categories to display on homepage', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of categories to display on homepage. (0 to disable)', TR_THEMENAMEOPTIONS ),
                'default' => '12',
                'min'     => '0',
                'step'    => '1',
                'max'     => '100',
            ),
            
            array(
                'id'      => 'pornstars_number',
                'type'    => 'spinner',
                'title'   => __( 'Number of pornstars to display on homepage', TR_THEMENAMEOPTIONS ),
                'desc'    => __( 'Enter the number of pornstars to display on homepage. (0 to disable)', TR_THEMENAMEOPTIONS ),
                'default' => '6',
                'min'     => '0',
                'step'    => '1',
                'max'     => '100',
            ),
                                    
            array(
                'id'       => 'categories_blog',
                'type'     => 'select',
                'data'     => 'categories',
                'title'    => __( 'Select the categories for Blog', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'These categories cease to appear in the lists of videos, galleries... and change the style to the same blog.', TR_THEMENAMEOPTIONS ),
                'default' => array(),
                'multi' => true
            ),
            
            array(
                'id'       => 'type_hd',
                'type'     => 'button_set',
                'title'    => __( 'Type Icon HD', TR_THEMENAMEOPTIONS ),
                'options'  => array(
                    '0' => __('Disable', TR_THEMENAMEOPTIONS),
                    '1' => __('Tag', TR_THEMENAMEOPTIONS),
                    '2' => __('Category', TR_THEMENAMEOPTIONS),
                ),
                'default'  => 0
            ),
            
            array(
                'id'       => 'categories_hd',
                'type'     => 'select',
                'data'     => 'categories',
                'title'    => __( 'Select the categories for icon HD', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'The categories that showed HD icon. If you use a category leave this field empty.', TR_THEMENAMEOPTIONS ),
                'required' => array('type_hd','equals','2'),
            ),
            
            array(
                'id'       => 'tags_hd',
                'type'     => 'select',
                'data'     => 'tags',
                'title'    => __( 'Select the tags for icon HD', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'The tags that showed HD icon. If you use a tag leave this field empty.', TR_THEMENAMEOPTIONS ),
                'required' => array('type_hd','equals','1'),
            ),
            
            array(
                'id'      => 'footer-text',
                'type'    => 'editor',
                'title'   => __( 'Footer text', TR_THEMENAMEOPTIONS ),
                'default' => __('To prevent the entry of minors, this site has been labeled by RTA (Restricted To Adults, restricted to adults, in Spanish). You can easily block access to this site by a filter navigation', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 5,
                    //'tabindex' => 1,
                    //'editor_css' => '',
                    'teeny'         => false,
                    //'tinymce' => array(),
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'=>'custom_header_code',
                'type' => 'textarea',
                'title' => __( 'Header code', TR_THEMENAMEOPTIONS ),
                'desc' => __( 'Enter special code. ( e.g.: Google analytics).', TR_THEMENAMEOPTIONS ),
                'default' => ''
            ),

            array(
                'id'=>'custom_footer_code',
                'type' => 'textarea',
                'title' => __( 'Footer code', TR_THEMENAMEOPTIONS ),
                'desc' => __( 'Enter special code. ( e.g.: Google analytics).', TR_THEMENAMEOPTIONS ),
                'default' => ''
            ),
            
        ),
    ));

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Advanced', TR_THEMENAMEOPTIONS ),
        'id'         => 'advanced',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            
            array(
                'id'       => 'speed',
                'type'     => 'switch',
                'title'    => __( 'Faster loading', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'Requires W3 Total Cache configured correctly', TR_THEMENAMEOPTIONS ),
                'default'  => false,
            ),
                        
            array(
                'id'       => 'tax_pornstars',
                'type'     => 'select',
                'data'     => 'taxonomies',
                'title'    => __( 'Select the taxonomy pornstars', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'No change if you do not know what is done.', TR_THEMENAMEOPTIONS ),
                'default' => 'pornstars'
            ),
            
            array(
                'id'       => 'create_tax_pornstars',
                'type'     => 'switch',
                'title'    => __( 'Create taxonomy pornstars', TR_THEMENAMEOPTIONS ),
                'desc' => __( 'No change if you do not know what is done', TR_THEMENAMEOPTIONS ),
                'default'  => true,
            ),
            
            array(
                'id'       => 'slug_pornstars',
                'type'     => 'text',
                'title'    => __( 'Slug pornstars', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'If you change need to <a target="_blank" href="'.get_option('home').'/wp-admin/options-permalink.php">update the permalinks</a>', TR_THEMENAMEOPTIONS ),
                'default'  => 'pornstars',
            ),
            
            array(
                'id'       => 'field_video',
                'type'     => 'text',
                'title'    => __( 'Custom Field Video', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'No change if you do not know what is done.', TR_THEMENAMEOPTIONS ),
                'default'  => __('video_iframe', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'       => 'field_time',
                'type'     => 'text',
                'title'    => __( 'Custom Field Duration', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'No change if you do not know what is done.', TR_THEMENAMEOPTIONS ),
                'default'  => __('duration', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'       => 'field_thumb',
                'type'     => 'text',
                'title'    => __( 'Custom Field Thumb', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'No change if you do not know what is done.', TR_THEMENAMEOPTIONS ),
                'default'  => __('thumb', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'       => 'field_link',
                'type'     => 'text',
                'title'    => __( 'Custom Field Link', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'No change if you do not know what is done.', TR_THEMENAMEOPTIONS ),
                'default'  => __('tr_link', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'       => 'filter_tax',
                'type'     => 'switch',
                'title'    => __( 'Filter taxonomy Galleries/Videos', TR_THEMENAMEOPTIONS ),
                'default'  => true,
            ),
            
            array(
                'id'       => 'the_content',
                'type'     => 'switch',
                'title'    => __( 'The_content video iframe', TR_THEMENAMEOPTIONS ),
                'default'  => false,
            ),
            
        ),
    ));

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Pages', TR_THEMENAMEOPTIONS ),
        'id'         => 'pages',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            
            array(
                'id'       => 'page-categories',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Select page categories', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Select the page to categories. Remember select the template page right after creating the page.', TR_THEMENAMEOPTIONS ),
            ),
            
            array(
                'id'       => 'page-cookies',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Select page cookies', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Select the page to cookies.', TR_THEMENAMEOPTIONS ),
            ),
            
            array(
                'id'       => 'page-newest',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Select page newest', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Select the page to newest. Remember select the template page right after creating the page.', TR_THEMENAMEOPTIONS ),
            ),
            
            array(
                'id'       => 'page-highest-rated',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Select page highest rated', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Select the page to highest rated. Remember select the template page right after creating the page.', TR_THEMENAMEOPTIONS ),
            ),
            
            array(
                'id'       => 'page-most-viewed',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Select page most viewed', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Select the page to most viewed. Remember select the template page right after creating the page.', TR_THEMENAMEOPTIONS ),
            ),
            
            array(
                'id'       => 'page-pornstars',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => __( 'Select page pornstars', TR_THEMENAMEOPTIONS ),
                'desc'     => __( 'Select the page to pornstars. Remember select the template page right after creating the page.', TR_THEMENAMEOPTIONS ),
            ),
            
        ),
    ));

   Redux::setSection( $opt_name, array(
        'title' => __( 'SEO', TR_THEMENAMEOPTIONS ),
        'id'    => 'seo',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-font'
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Titles', TR_THEMENAMEOPTIONS ),
        'id'         => 'titles',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(

            array(
                'id'      => 'h1_home',
                'type'    => 'editor',
                'title'   => __( 'HomePage', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('LATEST %sPORN VIDEOS%s', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_category',
                'type'    => 'editor',
                'title'   => __( 'Category', TR_THEMENAMEOPTIONS ),
                'default' => __('Porn Videos {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the category', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_post',
                'type'    => 'editor',
                'title'   => __( 'Post', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the entry', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_post_video',
                'type'    => 'editor',
                'title'   => __( 'Post Video', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the entry', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_post_gallery',
                'type'    => 'editor',
                'title'   => __( 'Post Gallery', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the entry', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            

            array(
                'id'      => 'h1_search',
                'type'    => 'editor',
                'title'   => __( 'Search', TR_THEMENAMEOPTIONS ),
                'default' => __('Search video {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the search', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_tag',
                'type'    => 'editor',
                'title'   => __( 'Tag', TR_THEMENAMEOPTIONS ),
                'default' => __('Tag video {name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the name of the tag', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            array(
                'id'      => 'h1_page',
                'type'    => 'editor',
                'title'   => __( 'Page', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display the title of the page', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_blog',
                'type'    => 'editor',
                'title'   => __( 'Blog', TR_THEMENAMEOPTIONS ),
                'default' => __('Blog', TR_THEMENAMEOPTIONS ),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_pornstars',
                'type'    => 'editor',
                'title'   => __( 'Pornstar', TR_THEMENAMEOPTIONS ),
                'default' => __('Pornstars', TR_THEMENAMEOPTIONS ),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_pornstars_single',
                'type'    => 'editor',
                'title'   => __( 'Single pornstar', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display name pornstar', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_countries',
                'type'    => 'editor',
                'title'   => __( 'Countries', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display term name', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_hair',
                'type'    => 'editor',
                'title'   => __( 'Hair', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display term name', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_ethnicity',
                'type'    => 'editor',
                'title'   => __( 'Ethnicity', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display term name', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_breasts',
                'type'    => 'editor',
                'title'   => __( 'Breasts', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display term name', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
            array(
                'id'      => 'h1_letter',
                'type'    => 'editor',
                'title'   => __( 'Letter', TR_THEMENAMEOPTIONS ),
                'default' => __('{name}', TR_THEMENAMEOPTIONS ),
                'desc' => __('{name} to display term name', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                )
            ),
            
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Subtitles', TR_THEMENAMEOPTIONS ),
        'id'         => 'subtitles',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            
            array(
                'id'      => 'h2_indexall',
                'type'    => 'editor',
                'title'   => __( 'Index all', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('LATEST %sPORN GALLERIES%s', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'required' => array('frontpage','equals','all'),
            ),
            
            array(
                'id'      => 'h2_randomgalleries',
                'type'    => 'editor',
                'title'   => __( 'Gallery random', TR_THEMENAMEOPTIONS ),
                'default' => __('RANDOM GALLERIES', TR_THEMENAMEOPTIONS),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'desc' => __('{name} to display the title of the post', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'      => 'h2_relatedgalleries',
                'type'    => 'editor',
                'title'   => __( 'Related galleries', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('RELATED %sPORN GALLERIES%s', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'desc' => __('{name} to display the title of the post', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'      => 'h2_relatedvideos',
                'type'    => 'editor',
                'title'   => __( 'Related videos', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('RELATED %sVIDEOS PORN%s', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'desc' => __('{name} to display the title of the post', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'      => 'h2_relatedpost',
                'type'    => 'editor',
                'title'   => __( 'Related post', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('RELATED %sPOST%s', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'desc' => __('{name} to display the title of the post', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'      => 'h2_relatedvideos_stars',
                'type'    => 'editor',
                'title'   => __( 'Related videos Pornstars', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('%s{total}%s VIDEOS PORN', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'desc' => __('{name} to display the name of the pornstars, {total} to display the count videos', TR_THEMENAMEOPTIONS),
            ),
            
            array(
                'id'      => 'h2_relatedgalleries_stars',
                'type'    => 'editor',
                'title'   => __( 'Related galleries Pornstars', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('%s{total}%s GALLERIES PORN', TR_THEMENAMEOPTIONS), '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'desc' => __('{name} to display the name of the pornstars, {total} to display the count videos', TR_THEMENAMEOPTIONS),
            ),
            
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __( 'Description', TR_THEMENAMEOPTIONS ),
        'id'         => 'description',
        'subsection' => true,
        'desc'       => '',
        'fields'     => array(
            
            array(
                'id'       => 'scroll_description',
                'type'     => 'switch',
                'title'    => __( 'Scroll in Description', TR_THEMENAMEOPTIONS ),
                'default'  => false,
            ),
            
            array(
                'id'       => 'position_description',
                'type'     => 'button_set',
                'title'    => __( 'Position', TR_THEMENAMEOPTIONS ),
                'options'  => array(
                    'top' => __('Top', TR_THEMENAMEOPTIONS),
                    'bottom' => __('Bottom', TR_THEMENAMEOPTIONS),
                ),
                'default'  => 'bottom'
            ),
            
            array(
                'id'      => 'description_categories',
                'type'    => 'editor',
                'title'   => __( 'Description categories', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('Enjoy over %s{total}%s videos on %s{name}%s. We have thousands of XXX videos dedicated to %s{name}%s. Learn about online videos on %s{name}%s Fuck me in here. Videos of %s{name}%s XXX doing all sorts of dirty tricks, free.', TR_THEMENAMEOPTIONS), '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => true,
                    'media_buttons' => false,
                    'textarea_rows' => 20,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'full_width' => true,
                'desc' => __('{name} to display the name of the pornstars, {total} to display the count post, {totalvideos} to display the count videos, {totalgalleries} to display the count galleries', TR_THEMENAMEOPTIONS),
                'subtitle' => __('Leave blank if you do not want to leave the description, if you want to customize it to the 100% category edit and put a description.', TR_THEMENAMEOPTIONS)
            ),
            
            array(
                'id'      => 'description_tag',
                'type'    => 'editor',
                'title'   => __( 'Description tags', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('Enjoy over %s{total}%s videos on %s{name}%s. We have thousands of XXX videos dedicated to %s{name}%s. Learn about online videos on %s{name}%s Fuck me in here. Videos of %s{name}%s XXX doing all sorts of dirty tricks, free.', TR_THEMENAMEOPTIONS), '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => true,
                    'media_buttons' => false,
                    'textarea_rows' => 20,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'full_width' => true,
                'desc' => __('{name} to display the name of the pornstars, {total} to display the count post.', TR_THEMENAMEOPTIONS),
                'subtitle' => __('Leave blank if you do not want to leave the description, if you want to customize it to the 100% tag edit and put a description.', TR_THEMENAMEOPTIONS)
            ),
            
            array(
                'id'      => 'description_pornstars',
                'type'    => 'editor',
                'title'   => __( 'Description pornstars', TR_THEMENAMEOPTIONS ),
                'default' => sprintf( __('Enjoy over %s{total}%s videos on %s{name}%s. We have thousands of XXX videos dedicated to %s{name}%s. Learn about online videos on %s{name}%s Fuck me in here. Videos of %s{name}%s XXX doing all sorts of dirty tricks, free.', TR_THEMENAMEOPTIONS), '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>', '<strong>', '</strong>'),
                'args'    => array(
                    'wpautop'       => true,
                    'media_buttons' => false,
                    'textarea_rows' => 20,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'full_width' => true,
                'desc' => __('{name} to display the name of the pornstars, {total} to display the count post, {totalvideos} to display the count videos, {totalgalleries} to display the count galleries', TR_THEMENAMEOPTIONS),
                'subtitle' => __('Leave blank if you do not want to leave the description, if you want to customize it to the 100% pornstar edit and put a description.', TR_THEMENAMEOPTIONS)
            ),
            
            array(
                'id'      => 'description_index',
                'type'    => 'editor',
                'title'   => __( 'Description FrontPage', TR_THEMENAMEOPTIONS ),
                'default' => '',
                'args'    => array(
                    'wpautop'       => true,
                    'media_buttons' => false,
                    'textarea_rows' => 20,
                    'teeny'         => false,
                    'quicktags'     => false,
                ),
                'full_width' => true,
                'subtitle' => __('Leave blank if you do not want to leave the description.', TR_THEMENAMEOPTIONS),
                'desc' => __('{total} to display the count post', TR_THEMENAMEOPTIONS),
            ),

        )
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'Advertising', TR_THEMENAMEOPTIONS ),
        'id'    => 'ads',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-list-alt',
        'fields'     => array(
            
            array(
                'id'         => 'ads_videos',
                'type'       => 'editor',
                'title'      => __( 'Ads videos right', TR_THEMENAMEOPTIONS ),
                'full_width' => true,
                'args'   => array(
                    'media_buttons' => false
                ),
                'subtitle' => __('Use more button to separate banners', TR_THEMENAMEOPTIONS),
                'default' => '<img src="'.get_template_directory_uri().'/img/cnt/dvr.jpg" alt="bnr">'."\n"."<!--more-->\n".'<img src="'.get_template_directory_uri().'/img/cnt/dvr.jpg" alt="bnr">'
            ),
            
            array(
                'id'         => 'ads_ft',
                'type'       => 'editor',
                'title'      => __( 'Ads footer', TR_THEMENAMEOPTIONS ),
                'full_width' => true,
                'args'   => array(
                    'media_buttons' => false
                ),
                'subtitle' => __('Use more button to separate banners', TR_THEMENAMEOPTIONS),
                'default' => '<img src="'.get_template_directory_uri().'/img/cnt/dvr.jpg" alt="bnr">'."\n"."<!--more-->\n".'<img src="'.get_template_directory_uri().'/img/cnt/dvr.jpg" alt="bnr">'."\n"."<!--more-->\n".'<img src="'.get_template_directory_uri().'/img/cnt/dvr.jpg" alt="bnr">'."\n"."<!--more-->\n".'<img src="'.get_template_directory_uri().'/img/cnt/dvr.jpg" alt="bnr">'
            ),
            
            array(
                'id'       => 'url_video',
                'type'     => 'text',
                'title'    => __( 'URL Video', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( '', TR_THEMENAMEOPTIONS ),
                'default'  => '#',
            ),
            
        ),
    ) );

   Redux::setSection( $opt_name, array(
        'title' => __( 'Design', TR_THEMENAMEOPTIONS ),
        'id'    => 'trdesign',
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'icon'  => 'el el-font'
    ) );

    Redux::setSection( $opt_name, array(
        'title' => __( 'General', TR_THEMENAMEOPTIONS ),
        'id'    => 'generaldesign',
        'subsection' => true,
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'fields'     => array(
            
            array(
                'id'       => 'logo',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Logo', TR_THEMENAMEOPTIONS ),
                'compiler' => 'false',
                'default'  => array( 'url' => get_template_directory_uri().'/img/torostars.png' ),
                'preview' => false
            ),
            
            array(
                'id'       => 'logoft',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Logo footer', TR_THEMENAMEOPTIONS ),
                'compiler' => 'false',
                'desc' => __('Leave blank to disable', TR_THEMENAMEOPTIONS),
                'default'  => array( 'url' => get_template_directory_uri().'/img/torostars-ft.png' ),
                'preview' => false
            ),
            
            array(
                'id'       => 'favicon',
                'type'     => 'media',
                'url'      => true,
                'title'    => __( 'Favicon', TR_THEMENAMEOPTIONS ),
                'compiler' => 'false',
                'default'  => array( 'url' => get_template_directory_uri().'/favicon.ico' ),
                'preview' => false
            ),
            
            array(
                'id'       => 'headerfx',
                'type'     => 'switch',
                'title'    => __( 'Header fixed', TR_THEMENAMEOPTIONS ),
                'default'  => false,
            ),
            
            array(
                'id'       => 'comments',
                'type'     => 'switch',
                'title'    => __( 'Comments', TR_THEMENAMEOPTIONS ),
                'default'  => true,
            ),
            
            array(
                'id'       => 'lazy',
                'type'     => 'switch',
                'title'    => __( 'Lazy load', TR_THEMENAMEOPTIONS ),
                'default'  => true,
            ),
            
            array(
                'id'       => 'boxed',
                'type'     => 'switch',
                'title'    => __( 'Boxed', TR_THEMENAMEOPTIONS ),
                'default'  => false,
            ),
            
            array(
                'id'       => 'header',
                'type'     => 'button_set',
                'title'    => __( 'Header', TR_THEMENAMEOPTIONS ),
                'options'  => array(
                    'default' => __('Default', TR_THEMENAMEOPTIONS),
                    'alt' => __('Alt', TR_THEMENAMEOPTIONS),
                ),
                'default'  => 'default'
            ),
            
            array(
                'id'       => 'sidebar',
                'type'     => 'button_set',
                'title'    => __( 'Sidebar', TR_THEMENAMEOPTIONS ),
                'options'  => array(
                    '1' => __('Left', TR_THEMENAMEOPTIONS),
                    '2' => __('Disable', TR_THEMENAMEOPTIONS),
                    '3' => __('Right', TR_THEMENAMEOPTIONS),
                ),
                'default'  => '1'
            ),
            
            array(
                'id'       => 'frontpage',
                'type'     => 'button_set',
                'title'    => __( 'Frontpage', TR_THEMENAMEOPTIONS ),
                'options'  => array(
                    'all' => __('All', TR_THEMENAMEOPTIONS),
                    'blog' => __('Blog', TR_THEMENAMEOPTIONS),
                    'columns' => __('Columns', TR_THEMENAMEOPTIONS),
                    'masonry' => __('Masonry', TR_THEMENAMEOPTIONS),
                    'tube' => __('Tube', TR_THEMENAMEOPTIONS),
                ),
                'default'  => 'all'
            ),

        ),
    ));

    Redux::setSection( $opt_name, array(
        'title' => __( 'Colors', TR_THEMENAMEOPTIONS ),
        'id'    => 'colors',
        'subsection' => true,
        'desc'  => __( '', TR_THEMENAMEOPTIONS ),
        'fields'     => array(
            
            array(
                'id'       => 'color',
                'type'     => 'button_set',
                'title'    => __( 'Color', TR_THEMENAMEOPTIONS ),
                'options'  => array(
                    '1' => __('Default', TR_THEMENAMEOPTIONS),
                    '2' => __('Dark', TR_THEMENAMEOPTIONS),
                    '3' => __('Alternative', TR_THEMENAMEOPTIONS),
                ),
                'default'  => '1'
            ),
            
            array(
                'id'       => 'css',
                'type'     => 'switch',
                'title'    => __( 'CSS Custom', TR_THEMENAMEOPTIONS ),
                'default'  => 0,
                'on'       => __( 'Enabled', TR_THEMENAMEOPTIONS ),
                'off'      => __( 'Disabled', TR_THEMENAMEOPTIONS ),
            ),
            
            /* DEFAULT */
            
            array(
                'id'     => 'info-general',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'GENERAL', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c1_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Body Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #313140.', TR_THEMENAMEOPTIONS ),
                'default'  => '#313140',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c1_default')
            ),
            
            array(
                'id'       => 'c2_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Text Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #B5B5BF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#B5B5BF',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c2_default')
            ),
            
            array(
                'id'       => 'c3_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Content Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F8F6FC.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F8F6FC',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c3_default')
            ),
            
            array(
                'id'       => 'c4_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Section Title Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c4_default')
            ),
            
            array(
                'id'       => 'c5_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Links Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c5_default')
            ),
            
            array(
                'id'       => 'c6_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Links Color (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FF6C71.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FF6C71',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c6_default')
            ),
            
            array(
                'id'     => 'info-hd',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'HEADER', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c7_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Header Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c7_default')
            ),
            
            array(
                'id'       => 'c8_default',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Header Background (Top)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','1'),
                'compiler' => array('.c8_default')
            ),
            
            array(
                'id'       => 'c9_default',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Header Background (Bot Header-Alt Menu Bar)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'required' => array('color','equals','1'),
                'compiler' => array('.c9_default')
            ),
            
            array(
                'id'     => 'info-menu',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'MENU', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c10_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c10_default')
            ),
            
            array(
                'id'       => 'c11_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c11_default')
            ),
            
            array(
                'id'       => 'c12_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Icon Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #B0B0C1.', TR_THEMENAMEOPTIONS ),
                'default'  => '#B0B0C1',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c12_default')
            ),
                        
            array(
                'id'       => 'c13_default',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Menu Item Background (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','1'),
                'compiler' => array('.c13_default')
            ),
            
            array(
                'id'       => 'c14_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Icon Color (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FF6C71.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FF6C71',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c14_default')
            ),
            
            array(
                'id'     => 'info-comments',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Comments', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c15_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Comment Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c15_default')
            ),
            
            array(
                'id'       => 'c16_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Comment Border-Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F3F2FB.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F3F2FB',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c16_default')
            ),
            
            array(
                'id'     => 'info-borders',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Borders', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c17_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Border Separation', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F3F2FB.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F3F2FB',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c17_default')
            ),
            
            array(
                'id'     => 'info-forms',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Form elements (Input/Textarea/etc...)', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c18_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Border Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F3F2FB.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F3F2FB',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c18_default')
            ),
            
            array(
                'id'       => 'c19_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Border (Focus)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FF6C71.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FF6C71',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c19_default')
            ),
            
            array(
                'id'       => 'c20_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c20_default')
            ),
            
            array(
                'id'       => 'c21_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Icons color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #E9E8F0.', TR_THEMENAMEOPTIONS ),
                'default'  => '#E9E8F0',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c21_default')
            ),
            
            array(
                'id'       => 'c22_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Icons color (Focus)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FF6C71.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FF6C71',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c22_default')
            ),
            
            array(
                'id'       => 'c23_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #626384.', TR_THEMENAMEOPTIONS ),
                'default'  => '#626384',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c23_default')
            ),
            
            array(
                'id'       => 'c24_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FF6C71.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FF6C71',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c24_default')
            ),
            
            array(
                'id'       => 'c25_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c25_default')
            ),
            
            array(
                'id'     => 'info-ratings',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Post Ratings', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c26_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Positive link color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #43c130.', TR_THEMENAMEOPTIONS ),
                'default'  => '#43c130',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c26_default')
            ),
            
            array(
                'id'       => 'c27_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Negative link color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F51824.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F51824',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c27_default')
            ),
            
            array(
                'id'       => 'c28_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background bar', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #43c130.', TR_THEMENAMEOPTIONS ),
                'default'  => '#43c130',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c28_default')
            ),
            
            array(
                'id'     => 'info-pornstars',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Porn Stars Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c29_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c29_default')
            ),
            
            array(
                'id'       => 'c30_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFF',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c30_default')
            ),
            
            array(
                'id'     => 'info-externalinks',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'External links Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c31_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c31_default')
            ),
            
            array(
                'id'       => 'c32_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','1'),
                'compiler' => array('.c32_default')
            ),
            
            array(
                'id'     => 'info-categories',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Categories Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
                        
            array(
                'id'       => 'c33_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: transparent.', TR_THEMENAMEOPTIONS ),
                'default'   => 'transparent',
                'required' => array('color','equals','1'),
                'compiler' => array('.c33_default'),
                'transparent' => 1
            ),
            
            array(
                'id'       => 'c34_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'required' => array('color','equals','1'),
                'compiler' => array('.c34_default'),
                'transparent' => false
            ),
            
            array(
                'id'     => 'info-footer',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Footer', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c35_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'required' => array('color','equals','1'),
                'compiler' => array('.c35_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c36_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Top)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'required' => array('color','equals','1'),
                'compiler' => array('.c36_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c37_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Mid)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'required' => array('color','equals','1'),
                'compiler' => array('.c37_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c38_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Bot)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'required' => array('color','equals','1'),
                'compiler' => array('.c38_default'),
                'transparent' => false
            ),
            
            array(
                'id'     => 'info-others',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Others', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','1'),
            ),
            
            array(
                'id'       => 'c39_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Header/Menus/Footer/Icons & Other things) Gral. #1', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'required' => array('color','equals','1'),
                'compiler' => array('.c39_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c40_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Hover/Current Links) Gral. #2', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FF6C71.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FF6C71',
                'required' => array('color','equals','1'),
                'compiler' => array('.c40_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c41_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Icons) Gral. #3', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #17B9C7.', TR_THEMENAMEOPTIONS ),
                'default'  => '#17B9C7',
                'required' => array('color','equals','1'),
                'compiler' => array('.c41_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c42_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Other things) Gral. #4', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #626384.', TR_THEMENAMEOPTIONS ),
                'default'  => '#626384',
                'required' => array('color','equals','1'),
                'compiler' => array('.c42_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c43_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background ScrollBar (Only in Chrome/Safari-Webkit browsers)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ddd.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ddd',
                'required' => array('color','equals','1'),
                'compiler' => array('.c43_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c44_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background ScrollBar-Thumb', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #17B9C7.', TR_THEMENAMEOPTIONS ),
                'default'  => '#17B9C7',
                'required' => array('color','equals','1'),
                'compiler' => array('.c44_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c45_default',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Post info (Bar)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#FFFFFF',
                    'alpha'     => 0.9
                ),
                'required' => array('color','equals','1'),
                'compiler' => array('.c45_default'),
                'transparent' => false
            ),
                        
            array(
                'id'       => 'c46_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Widgets/Post/Content Backgorund', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'required' => array('color','equals','1'),
                'compiler' => array('.c46_default'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c47_default',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Special Widget', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'required' => array('color','equals','1'),
                'compiler' => array('.c47_default'),
                'transparent' => false
            ),
            
            /* DARK */
            
            array(
                'id'     => 'info-general-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'GENERAL', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c1_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Body Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #31353C.', TR_THEMENAMEOPTIONS ),
                'default'  => '#31353C',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c1_dark'),
            ),
            
            array(
                'id'       => 'c2_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Text Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => array( 
                    'color' => '#FFFFFF',
                    'alpha' => 0.5
                ),
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c2_dark')
            ),
            
            array(
                'id'       => 'c3_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Content Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c3_dark')
            ),
            
            array(
                'id'       => 'c4_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Section Title Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c4_dark')
            ),
            
            array(
                'id'       => 'c5_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Links Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c5_dark')
            ),
            
            array(
                'id'       => 'c6_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Links Color (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c6_dark')
            ),
            
            array(
                'id'     => 'info-hd-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'HEADER', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c7_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Header Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c7_dark')
            ),
            
            array(
                'id'       => 'c8_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Header Background (Top)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','2'),
                'compiler' => array('.c8_dark')
            ),
            
            array(
                'id'       => 'c9_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Header Background (Bot Header-Alt Menu Bar)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'required' => array('color','equals','2'),
                'compiler' => array('.c9_dark')
            ),
            
            array(
                'id'     => 'info-menu-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'MENU', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c10_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c10_dark')
            ),
            
            array(
                'id'       => 'c11_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Menu Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#FFFFFF',
                    'alpha'     => 0.5
                ),
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c11_dark')
            ),
            
            array(
                'id'       => 'c12_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Icon Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #B0B0C1.', TR_THEMENAMEOPTIONS ),
                'default'  => '#B0B0C1',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c12_dark')
            ),
                        
            array(
                'id'       => 'c13_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Menu Item Background (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','2'),
                'compiler' => array('.c13_dark')
            ),
            
            array(
                'id'       => 'c14_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Icon Color (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c14_dark')
            ),
            
            array(
                'id'     => 'info-comments-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Comments', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c15_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Comment Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c15_dark')
            ),
            
            array(
                'id'       => 'c16_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Comment Border-Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c16_dark')
            ),
            
            array(
                'id'     => 'info-borders-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Borders', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c17_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Border Separation', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.1
                ),
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c17_dark')
            ),
            
            array(
                'id'     => 'info-forms-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Form elements (Input/Textarea/etc...)', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c18_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Border Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#FFFFFF',
                    'alpha'     => 0.1
                ),
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c18_dark')
            ),
            
            array(
                'id'       => 'c19_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Border (Focus)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c19_dark')
            ),
            
            array(
                'id'       => 'c20_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #383F49.', TR_THEMENAMEOPTIONS ),
                'default'  => '#383F49',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c20_dark')
            ),
            
            array(
                'id'       => 'c21_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Icons color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #E9E8F0.', TR_THEMENAMEOPTIONS ),
                'default'  => '#E9E8F0',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c21_dark')
            ),
            
            array(
                'id'       => 'c22_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Icons color (Focus)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c22_dark')
            ),
            
            array(
                'id'       => 'c23_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #141D26.', TR_THEMENAMEOPTIONS ),
                'default'  => '#141D26',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c23_dark')
            ),
            
            array(
                'id'       => 'c24_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c24_dark')
            ),
            
            array(
                'id'       => 'c25_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c25_dark')
            ),
            
            array(
                'id'     => 'info-ratings-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Post Ratings', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c26_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Positive link color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #43c130.', TR_THEMENAMEOPTIONS ),
                'default'  => '#43c130',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c26_dark')
            ),
            
            array(
                'id'       => 'c27_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Negative link color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F51824.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F51824',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c27_dark')
            ),
            
            array(
                'id'       => 'c28_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background bar', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #43c130.', TR_THEMENAMEOPTIONS ),
                'default'  => '#43c130',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c28_dark')
            ),
            
            array(
                'id'     => 'info-pornstars-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Porn Stars Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c29_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c29_dark')
            ),
            
            array(
                'id'       => 'c30_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFF',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c30_dark')
            ),
            
            array(
                'id'     => 'info-externalinks-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'External links Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c31_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c31_dark')
            ),
            
            array(
                'id'       => 'c32_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','2'),
                'compiler' => array('.c32_dark')
            ),
            
            array(
                'id'     => 'info-categories-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Categories Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
                        
            array(
                'id'       => 'c33_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'   => '#434A54',
                'required' => array('color','equals','2'),
                'compiler' => array('.c33_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c34_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'required' => array('color','equals','2'),
                'compiler' => array('.c34_dark'),
                'transparent' => false
            ),
            
            array(
                'id'     => 'info-footer-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Footer', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c35_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'required' => array('color','equals','2'),
                'compiler' => array('.c35_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c36_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Top)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','2'),
                'compiler' => array('.c36_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c37_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Mid)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'required' => array('color','equals','2'),
                'compiler' => array('.c37_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c38_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Bot)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #434A54.', TR_THEMENAMEOPTIONS ),
                'default'  => '#434A54',
                'required' => array('color','equals','2'),
                'compiler' => array('.c38_dark'),
                'transparent' => false
            ),
            
            array(
                'id'     => 'info-others-2',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Others', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','2'),
            ),
            
            array(
                'id'       => 'c39_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Header/Menus/Footer/Icons & Other things) Gral. #1', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #A1A9AE.', TR_THEMENAMEOPTIONS ),
                'default'  => '#A1A9AE',
                'required' => array('color','equals','2'),
                'compiler' => array('.c39_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c40_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Hover/Current Links) Gral. #2', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'required' => array('color','equals','2'),
                'compiler' => array('.c40_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c41_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Icons) Gral. #3', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'required' => array('color','equals','2'),
                'compiler' => array('.c41_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c42_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Other things) Gral. #4', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #A1A9AE.', TR_THEMENAMEOPTIONS ),
                'default'  => '#A1A9AE',
                'required' => array('color','equals','2'),
                'compiler' => array('.c42_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c43_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background ScrollBar (Only in Chrome/Safari-Webkit browsers)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ddd.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ddd',
                'required' => array('color','equals','2'),
                'compiler' => array('.c43_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c44_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background ScrollBar-Thumb', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ED5564.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ED5564',
                'required' => array('color','equals','2'),
                'compiler' => array('.c44_dark'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c45_dark',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Post info (Bar)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.8
                ),
                'required' => array('color','equals','2'),
                'compiler' => array('.c45_dark'),
                'transparent' => false
            ),
                        
            array(
                'id'       => 'c46_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Widgets/Post/Content Backgorund', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #363B43.', TR_THEMENAMEOPTIONS ),
                'default'   => '#363B43',
                'required' => array('color','equals','2'),
                'compiler' => array('.c46_dark')
            ),
            
            array(
                'id'       => 'c47_dark',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Special Widget', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #141D26.', TR_THEMENAMEOPTIONS ),
                'default'  => '#141D26',
                'required' => array('color','equals','2'),
                'compiler' => array('.c47_dark'),
                'transparent' => false
            ),

            /* ALTERNATIVE */
            
            array(
                'id'     => 'info-general-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'GENERAL', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c1_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Body Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #111111.', TR_THEMENAMEOPTIONS ),
                'default'  => '#111111',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c1_alternative'),
            ),
            
            array(
                'id'       => 'c2_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Text Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#FFFFFF',
                    'alpha'     => 0.5
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c2_alternative')
            ),
            
            array(
                'id'       => 'c3_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Content Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #252525.', TR_THEMENAMEOPTIONS ),
                'default'  => '#252525',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c3_alternative')
            ),
            
            array(
                'id'       => 'c4_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Section Title Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c4_alternative')
            ),
            
            array(
                'id'       => 'c5_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Links Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c5_alternative')
            ),
            
            array(
                'id'       => 'c6_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Links Color (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c6_alternative')
            ),
            
            array(
                'id'     => 'info-hd-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'HEADER', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c7_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Header Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #42435B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#42435B',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c7_alternative')
            ),
            
            array(
                'id'       => 'c8_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Header Background (Top)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #C4371B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#C4371B',
                'required' => array('color','equals','3'),
                'compiler' => array('.c8_alternative')
            ),
            
            array(
                'id'       => 'c9_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Header Background (Bot Header-Alt Menu Bar)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'required' => array('color','equals','3'),
                'compiler' => array('.c9_alternative')
            ),
            
            array(
                'id'     => 'info-menu-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'MENU', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c10_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #C4371B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#C4371B',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c10_alternative')
            ),
            
            array(
                'id'       => 'c11_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c11_alternative')
            ),
            
            array(
                'id'       => 'c12_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Menu Icon Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#FFFFFF',
                    'alpha'     => 0.5
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c12_alternative')
            ),
                        
            array(
                'id'       => 'c13_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Menu Item Background (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','3'),
                'compiler' => array('.c13_alternative')
            ),
            
            array(
                'id'       => 'c14_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Menu Icon Color (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c14_alternative')
            ),
            
            array(
                'id'     => 'info-comments-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Comments', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c15_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Comment Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #333.', TR_THEMENAMEOPTIONS ),
                'default'  => '#333',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c15_alternative')
            ),
            
            array(
                'id'       => 'c16_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Comment Border-Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #444.', TR_THEMENAMEOPTIONS ),
                'default'  => '#444',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c16_alternative')
            ),
            
            array(
                'id'     => 'info-borders-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Borders', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c17_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Border Separation', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F3F2FB.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c17_alternative')
            ),
            
            array(
                'id'     => 'info-forms-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Form elements (Input/Textarea/etc...)', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c18_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Border Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F3F2FB.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c18_alternative')
            ),
            
            array(
                'id'       => 'c19_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Border (Focus)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c19_alternative')
            ),
            
            array(
                'id'       => 'c20_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c20_alternative')
            ),
            
            array(
                'id'       => 'c21_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Icons color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#FFFFFF',
                    'alpha'     => 0.3
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c21_alternative')
            ),
            
            array(
                'id'       => 'c22_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Icons color (Focus)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c22_alternative')
            ),
            
            array(
                'id'       => 'c23_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #D19600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#D19600',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c23_alternative')
            ),
            
            array(
                'id'       => 'c24_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons (Hover)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c24_alternative')
            ),
            
            array(
                'id'       => 'c25_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background Buttons Color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFFFFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFFFFF',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c25_alternative')
            ),
            
            array(
                'id'     => 'info-ratings-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Post Ratings', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c26_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Positive link color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #43c130.', TR_THEMENAMEOPTIONS ),
                'default'  => '#43c130',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c26_alternative')
            ),
            
            array(
                'id'       => 'c27_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Negative link color', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F51824.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F51824',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c27_alternative')
            ),
            
            array(
                'id'       => 'c28_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background bar', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #43c130.', TR_THEMENAMEOPTIONS ),
                'default'  => '#43c130',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c28_alternative')
            ),
            
            array(
                'id'     => 'info-pornstars-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Porn Stars Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c29_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c29_alternative')
            ),
            
            array(
                'id'       => 'c30_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFF',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c30_alternative')
            ),
            
            array(
                'id'     => 'info-externalinks-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'External links Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c31_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c31_alternative')
            ),
            
            array(
                'id'       => 'c32_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #FFF.', TR_THEMENAMEOPTIONS ),
                'default'  => '#FFF',
                'transparent' => false,
                'required' => array('color','equals','3'),
                'compiler' => array('.c32_alternative')
            ),
            
            array(
                'id'     => 'info-categories-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Categories Section', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
                        
            array(
                'id'       => 'c33_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #252525.', TR_THEMENAMEOPTIONS ),
                'default'   => '#252525',
                'required' => array('color','equals','3'),
                'compiler' => array('.c33_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c34_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Title', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #fff.', TR_THEMENAMEOPTIONS ),
                'default'  => '#fff',
                'required' => array('color','equals','3'),
                'compiler' => array('.c34_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'     => 'info-footer-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Footer', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c35_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #C4371B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#C4371B',
                'required' => array('color','equals','3'),
                'compiler' => array('.c35_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c36_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Top)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.5
                ),
                'required' => array('color','equals','3'),
                'compiler' => array('.c36_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c37_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Mid)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.4
                ),
                'required' => array('color','equals','3'),
                'compiler' => array('.c37_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c38_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Footer Background (Bot)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.2
                ),
                'required' => array('color','equals','3'),
                'compiler' => array('.c38_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'     => 'info-others-3',
                'type'   => 'info',
                'notice' => false,
                'title'  => __( 'Others', TR_THEMENAMEOPTIONS ),
                'required' => array('color','equals','3'),
            ),
            
            array(
                'id'       => 'c39_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Header/Menus/Footer/Icons & Other things) Gral. #1', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #D19600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#D19600',
                'required' => array('color','equals','3'),
                'compiler' => array('.c39_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c40_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Hover/Current Links) Gral. #2', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'required' => array('color','equals','3'),
                'compiler' => array('.c40_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c41_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Icons) Gral. #3', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #04BD9D.', TR_THEMENAMEOPTIONS ),
                'default'  => '#04BD9D',
                'required' => array('color','equals','3'),
                'compiler' => array('.c41_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c42_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background/Color (Other things) Gral. #4', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #D19600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#D19600',
                'required' => array('color','equals','3'),
                'compiler' => array('.c42_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c43_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background ScrollBar (Only in Chrome/Safari-Webkit browsers)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #ddd.', TR_THEMENAMEOPTIONS ),
                'default'  => '#ddd',
                'required' => array('color','equals','3'),
                'compiler' => array('.c43_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c44_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Background ScrollBar-Thumb', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #F4C600.', TR_THEMENAMEOPTIONS ),
                'default'  => '#F4C600',
                'required' => array('color','equals','3'),
                'compiler' => array('.c44_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c45_alternative',
                'type'     => 'color_rgba',
                'output'   => array( '' ),
                'title'    => __( 'Post info (Bar)', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #000000.', TR_THEMENAMEOPTIONS ),
                'default'   => array(
                    'color'     => '#000000',
                    'alpha'     => 0.7
                ),
                'required' => array('color','equals','3'),
                'compiler' => array('.c45_alternative'),
                'transparent' => false
            ),
            
            array(
                'id'       => 'c46_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Widgets/Post/Content Backgorund', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #1E1E1E.', TR_THEMENAMEOPTIONS ),
                'default'  => '#1E1E1E',
                'required' => array('color','equals','3'),
                'compiler' => array('.c46_alternative')
            ),
            
            array(
                'id'       => 'c47_alternative',
                'type'     => 'color',
                'output'   => array( '' ),
                'title'    => __( 'Special Widget', TR_THEMENAMEOPTIONS ),
                'subtitle' => __( 'default: #C4371B.', TR_THEMENAMEOPTIONS ),
                'default'  => '#C4371B',
                'required' => array('color','equals','3'),
                'compiler' => array('.c47_alternative'),
                'transparent' => false
            ),
            
        ),
    ) );

    /*
     * <--- END SECTIONS
     */

    function tr_compiler_action( $options, $css, $changed_values ) {
        global $wp_filesystem;
        
        if($options['color']==1) { $filecss='create_default.css'; }
        if($options['color']==2) { $filecss='create_black.css'; }
        if($options['color']==3) { $filecss='create_alternative.css'; }
 
        $filename = get_stylesheet_directory(). '/'.$filecss;

        if( empty( $wp_filesystem ) ) {
            require_once( ABSPATH .'/wp-admin/includes/file.php' );
            WP_Filesystem();
        }
                
        $css='';
        /* TTCLRS */        
        if($options['color']==1) { // default TTCLR-A

            if($options['c1_default']==''){$options['c1_default']='#313140';}
            if($options['c2_default']==''){$options['c2_default']='#B5B5BF';}
            if($options['c3_default']==''){$options['c3_default']='#F8F6FC';}
            if($options['c4_default']==''){$options['c4_default']='#42435B';}
            if($options['c5_default']==''){$options['c5_default']='#42435B';}
            if($options['c6_default']==''){$options['c6_default']='#FF6C71';}
            if($options['c7_default']==''){$options['c7_default']='#42435B';}
            if($options['c8_default']['rgba']==''){$options['c8_default']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c9_default']['rgba']==''){$options['c9_default']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c10_default']==''){$options['c10_default']='#42435B';}
            if($options['c11_default']==''){$options['c11_default']='#fff';}
            if($options['c12_default']==''){$options['c12_default']='#B0B0C1';}
            if($options['c13_default']['rgba']==''){$options['c13_default']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c14_default']==''){$options['c14_default']='#FF6C71';}
            if($options['c15_default']==''){$options['c15_default']='#fff';}
            if($options['c16_default']==''){$options['c16_default']='#F3F2FB';}
            if($options['c17_default']==''){$options['c17_default']='#F3F2FB';}
            if($options['c18_default']==''){$options['c18_default']='#F3F2FB';}
            if($options['c19_default']==''){$options['c19_default']='#FF6C71';}
            if($options['c20_default']==''){$options['c20_default']='#fff';}
            if($options['c21_default']==''){$options['c21_default']='#E9E8F0';}
            if($options['c22_default']==''){$options['c22_default']='#FF6C71';}
            if($options['c23_default']==''){$options['c23_default']='#626384';}
            if($options['c24_default']==''){$options['c24_default']='#FF6C71';}
            if($options['c25_default']==''){$options['c25_default']='#fff';}
            if($options['c26_default']==''){$options['c26_default']='#43c130';}
            if($options['c27_default']==''){$options['c27_default']='#F51824';}
            if($options['c28_default']==''){$options['c28_default']='#43c130';}
            if($options['c29_default']==''){$options['c29_default']='#42435B';}
            if($options['c30_default']==''){$options['c30_default']='#fff';}
            if($options['c31_default']==''){$options['c31_default']='#fff';}
            if($options['c32_default']==''){$options['c32_default']='#42435B';}
            if($options['c33_default']==''){$options['c33_default']='transparent';}
            if($options['c34_default']==''){$options['c34_default']='#42435B';}
            if($options['c35_default']==''){$options['c35_default']='#42435B';}
            if($options['c36_default']==''){$options['c36_default']='#fff';}
            if($options['c37_default']==''){$options['c37_default']='#42435B';}
            if($options['c38_default']==''){$options['c38_default']='#fff';}
            if($options['c39_default']==''){$options['c39_default']='#42435B';}
            if($options['c40_default']==''){$options['c40_default']='#FF6C71';}
            if($options['c41_default']==''){$options['c41_default']='#17B9C7';}
            if($options['c42_default']==''){$options['c42_default']='#626384';}
            if($options['c43_default']==''){$options['c43_default']='#ddd';}
            if($options['c44_default']==''){$options['c44_default']='#17B9C7';}
            if($options['c45_default']['rgba']==''){$options['c45_default']['rgba']='rgba(255,255,255,0.9)';}
            if($options['c46_default']==''){$options['c46_default']='#fff';}
            if($options['c47_default']==''){$options['c47_default']='#42435B';}            
            
/* General */
            // COLOR 01  Body Background
            $css.='body{background-color:'.$options['c1_default'].'}'."\n";
            // COLOR 02  Text Color
            $css.='body{color:'.$options['c2_default'].'}'."\n";
            // COLOR 03  Content Background
            $css.='.Body{background-color:'.$options['c3_default'].'}'."\n";
            // COLOR 04  Section Title Color
            $css.='.SectionTitle,.SectionTitle.Clr1,.TtPornText h1,.textwidget h1,.TtPornText h2,.textwidget h2,.TtPornText h3,.textwidget h3,.TtPornText h4,.textwidget h4,.TtPornText h5,.textwidget h5,.TtPornText h6,.textwidget h6{color:'.$options['c4_default'].'}'."\n";
            // COLOR 05  Links Color
            $css.='a{color:'.$options['c5_default'].'}';
            // COLOR 06  Links Color (Hover)
            $css.='a:hover,.tagcloud a:before{color:'.$options['c6_default'].'}';
            
/* Header */            
            // COLOR 07  Header Background
            $css.='.Header{background-color:'.$options['c7_default'].'}';
            // COLOR 08  Header Background (Top)
            $css.='.HeaderTop{background-color:'.$options['c8_default']['rgba'].'}';
            // COLOR 09  Header Background (Bot Header-Alt Menu Bar)
            $css.='.HeaderBot{background-color:'.$options['c9_default']['rgba'].'}';
                    
/* Menu */
            // COLOR 10  Menu Background
            $css.='.TtMenu,.TtMenu .menu-item-has-children>ul{background-color:'.$options['c10_default'].'}';
            // COLOR 11  Menu Color
            $css.='.TtMenu,.TtMenu a{color:'.$options['c11_default'].'}';
            // COLOR 12  Menu Icon Color
            $css.='.TtMenu>ul>li:before{color:'.$options['c12_default'].'}';
            // COLOR 13  Menu Item Background (Hover)
            $css.='.TtMenu li:hover{background-color:'.$options['c13_default']['rgba'].'}';
            // COLOR 14  Menu Icon Color (Hover)
            $css.='.TtMenu>ul>li:hover:before{color:'.$options['c14_default'].'}';
            
/* Comments*/
            // COLOR 15  Comment Background
            $css.='.Comment>div{background-color:'.$options['c15_default'].'}';
            $css.='.Comment>div:after{border-right-color:'.$options['c15_default'].'!important}';
            // COLOR 16  Comment Border-Color
            $css.='.Comment>div,.Comment figure img{border-color:'.$options['c16_default'].'}';
            $css.='.Comment>div:before{border-right-color:'.$options['c16_default'].'}';

/* Borders*/
            // COLOR 17  Border Separation
            $css.='.ListCommts+.RespondTt:before,.TtPornInfo:before,.ListPornInfo.Top:after{background-color:'.$options['c17_default'].'}';
            $css.='.TtBxTp,.ListAlph>li>a,.SwHdBtn:before,.ClpsCn>.ClpsTp{border-color:'.$options['c17_default'].'}';

/*  Form elements (Input/Textarea/etc...) */
            // COLOR 18  Border Color
            $css.='input,textarea,select,.Select label,.ListFilter label{border-color:'.$options['c18_default'].'}';
            // COLOR 19  Border (Focus)
            $css.='input:focus,textarea:focus,select:focus,.Select label:focus{border-color:'.$options['c19_default'].'}';
            // COLOR 20  Background
            $css.='input,textarea,select,.Select label,.ListFilter label{background-color:'.$options['c20_default'].'}';
            // COLOR 21  Icons color
            $css.='.Form-Icon input+i,.Form-Icon textarea+i{color:'.$options['c21_default'].'}';
            // COLOR 22  Icons color (Focus)
            $css.='.Form-Icon input:focus+i,.Form-Icon textarea:focus+i{color:'.$options['c22_default'].'}';

/* Buttons */
            // COLOR 23  Background Buttons
            $css.='.Button,a.Button,button,input[type="button"],input[type="reset"],input[type="submit"]{background-color:'.$options['c23_default'].'}';
            // COLOR 24  Background Buttons (Hover)
            $css.='.Button:hover,a.Button:hover,button:hover,input[type="button"]:hover,input[type="reset"]:hover,input[type="submit"]:hover{background-color:'.$options['c24_default'].'}';
            // COLOR 25  Background Buttons Color
            $css.='.Button,a.Button,button,input[type="button"],input[type="reset"],input[type="submit"]{color:'.$options['c25_default'].'}';

/* Post Ratings*/
            // COLOR 26  Positive link color
            $css.='.Tt-Votes a.Tt-VoteUp{color:'.$options['c26_default'].'}';
            // COLOR 27  Negative link color
            $css.='.Tt-Votes a.Tt-VoteDown{color:'.$options['c27_default'].'}';
            // COLOR 28  Background bar
            $css.='.Tt-Bar>div{background-color:'.$options['c28_default'].'}';

/* Porn Stars Section */
            // COLOR 29  Background
            $css.='.PornStars{background-color:'.$options['c29_default'].'}';
            // COLOR 30  Title
            $css.='.PornStars .SectionTitle{color:'.$options['c30_default'].'}';
            
/* External links Section*/
            // COLOR 31  Background
            $css.='.ExternalLnks{background-color:'.$options['c31_default'].'}';
            // COLOR 32  Title
            $css.='.ExternalLnks .SectionTitle{color:'.$options['c32_default'].'}';

/* Categories Section */
            // COLOR 33  Background
            $css.='.Categories{background-color:'.$options['c33_default'].'}';
            // COLOR 34  Title
            $css.='.Categories .SectionTitle{color:'.$options['c34_default'].'}';

/* Footer*/
            // COLOR 35  Footer Background
            $css.='.Footer{background-color:'.$options['c35_default'].'}';
            // COLOR 36  Footer Background (Top)
            $css.='.FooterTop{background-color:'.$options['c36_default'].'}';
            // COLOR 37  Footer Background (Mid)
            $css.='.FooterMid{background-color:'.$options['c37_default'].'}';
            // COLOR 38  Footer Background (Bot)
            $css.='.FooterBot{background-color:'.$options['c38_default'].'}';

/* Others */
            // COLOR 39  Background/Color (Header/Menus/Footer/Icons & Other things) Gral. #1
            $css.='.Bgc1,.Bgc1B:Before,.ListExtLnks>li>a,.ListAlph.Top>li>a,.widget_calendar table caption,.error-404 .Search{background-color:'.$options['c39_default'].'}';
            $css.='.Clr1,.Clr1B:before,.SubsBx button,.Tt-Percent,.TtBxCn button.ClearFilter,.widget_calendar thead th{color:'.$options['c39_default'].'}';
            $css.='@media all and (max-width: 950px){.TtDwMenu,.TtMenuFt ul{background-color:'.$options['c39_default'].'}}';
            $css.='@media all and (min-width: 1400px){.ListAlph.Top{background-color:'.$options['c39_default'].'}}';
            
            // COLOR 40  Background/Color (Hover/Current Links) Gral. #2
            $css.='.TtBxCn .TtBxTp+ul li:hover,.widget_nav_menu div ul li:hover,.Bgc2,.Bgc2B:before,div.wp-pagenavi a:hover,div.wp-pagenavi span.current,.ListExtLnks>li>a:hover,.ListAlph>li.Current>a,.ListAlph>li.Current:hover>a,.Button.Current,#wp-calendar #today,.page-links>a:hover,.page-links>span{background-color:'.$options['c40_default'].'}';
            $css.='@media all and (max-width: 950px){#TtDwMenu:checked~.TtDwMenu,#TtDwMenu.slvzr-checked~.TtDwMenu{background-color:'.$options['c40_default'].'}}';
            $css.='.ListFilter label:hover,.ListFilter input:checked+label,.ListFilter input.slvzr-checked+label{border-color:'.$options['c40_default'].'}';
            $css.='.Clr2,.Clr2B:before,.FooterMid .TtMenu>ul>li:hover:before,.SubsBx button:hover,.ListFilter input:checked+label,.ListFilter input.slvzr-checked+label,.ListFilter label:hover,.TtBxCn button.ClearFilter span,.comment-reply-link:before,.PostInt h1,.Tt-VoteDown,.TtBxCn button.ClearFilter:hover,.cancel-comment-reply a:before,.TtMenuFt li[class*="fa-"]:hover:before{color:'.$options['c40_default'].'}';

            // COLOR 41  Background/Color (Icons) Gral. #3
            $css.='.SectionTitle[class*="fa-"]:before,.Bgc3,.Bgc3B:before,.Tt-Bar>div,.mCS-default .mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar,.Button.Download,.HdCookie,.page-links>span.page-links-title,.TtPornText h1:after,.textwidget h1:after,.TtPornText h2:after,.textwidget h2:after,.TtPornText h3:after,.textwidget h3:after{background-color:'.$options['c41_default'].'}';
            $css.='.Post .OutPst:after{border-top-color:'.$options['c41_default'].'}';
            $css.='.Clr3,.Clr3B:before,a.Tt-Like:before,a.Tt-Like:hover,a.Tt-VoteUp,.CkCnt .Button:before{color:'.$options['c41_default'].'}';

            // COLOR 42  Background/Color (Other things) Gral. #4
            $css.='.ListAlph>li:hover>a,.Tt-Bar,div.wp-pagenavi a,div.wp-pagenavi span,.page-links>a,.page-links>span,.HDPst{background-color:'.$options['c42_default'].'}';

            // COLOR 43  Background ScrollBar (Only in Chrome/Safari-Webkit browsers)
            $css.='::-webkit-scrollbar{background-color:'.$options['c43_default'].'}';

            // COLOR 44  Background ScrollBar-Thumb
            $css.='::-webkit-scrollbar-thumb{background-color:'.$options['c44_default'].'}';

            // COLOR 45  Post info (Bar)
            $css.='.Post .Info{background-color:'.$options['c45_default']['rgba'].'}';

            // COLOR 46  Widgets/Post/Content Backgorund
            $css.='.TtBxCn,.ListCate .Cate,.PostInt,.ClpsCn>.ClpsTp.SectionTitle,.ClpsBd>div,.ListPost>li:before,.ListPornStar>li:before,.SiteInfo{background-color:'.$options['c46_default'].'}';
            $css.='@media all and (min-width: 950px){.TtStyA .Post header{background-color:'.$options['c46_default'].'}}';

            // COLOR 47  Special Widget
            $css.='.TtBxCn.Dark{background-color:'.$options['c47_default'].'}';
            
        }elseif($options['color']==2) { // dark TTCLR-B

            if($options['c1_dark']==''){$options['c1_dark']='#31353C';}
            if($options['c2_dark']['rgba']==''){$options['c2_dark']['rgba']='rgba(255,255,255,0.5)';}
            if($options['c3_dark']==''){$options['c3_dark']='#434A54';}
            if($options['c4_dark']==''){$options['c4_dark']='#fff';}
            if($options['c5_dark']==''){$options['c5_dark']='#fff';}
            if($options['c6_dark']==''){$options['c6_dark']='#ED5564';}
            if($options['c7_dark']==''){$options['c7_dark']='#434A54';}
            if($options['c8_dark']['rgba']==''){$options['c8_dark']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c9_dark']['rgba']==''){$options['c9_dark']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c10_dark']==''){$options['c10_dark']='#434A54';}
            if($options['c11_dark']['rgba']==''){$options['c11_dark']['rgba']='rgba(255,255,255,0.5)';}
            if($options['c12_dark']==''){$options['c12_dark']='#B0B0C1';}
            if($options['c13_dark']['rgba']==''){$options['c13_dark']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c14_dark']==''){$options['c14_dark']='#ED5564';}
            if($options['c15_dark']==''){$options['c15_dark']='#434A54';}
            if($options['c16_dark']==''){$options['c16_dark']='#434A54';}
            if($options['c17_dark']['rgba']==''){$options['c17_dark']['rgba']='rgba(0,0,0,0.1)';}
            if($options['c18_dark']['rgba']==''){$options['c18_dark']['rgba']='rgba(255,255,255,0.1)';}
            if($options['c19_dark']==''){$options['c19_dark']='#ED5564';}
            if($options['c20_dark']==''){$options['c20_dark']='#383F49';}
            if($options['c21_dark']==''){$options['c21_dark']='#E9E8F0';}
            if($options['c22_dark']==''){$options['c22_dark']='#ED5564';}
            if($options['c23_dark']==''){$options['c23_dark']='#141D26';}
            if($options['c24_dark']==''){$options['c24_dark']='#ED5564';}
            if($options['c25_dark']==''){$options['c25_dark']='#fff';}
            if($options['c26_dark']==''){$options['c26_dark']='#43c130';}
            if($options['c27_dark']==''){$options['c27_dark']='#F51824';}
            if($options['c28_dark']==''){$options['c28_dark']='#43c130';}
            if($options['c29_dark']['rgba']==''){$options['c29_dark']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c30_dark']==''){$options['c30_dark']='#fff';}
            if($options['c31_dark']['rgba']==''){$options['c31_dark']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c32_dark']==''){$options['c32_dark']='#fff';}
            if($options['c33_dark']==''){$options['c33_dark']='#434A54';}
            if($options['c34_dark']==''){$options['c34_dark']='#fff';}
            if($options['c35_dark']==''){$options['c35_dark']='#434A54';}
            if($options['c36_dark']['rgba']==''){$options['c36_dark']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c37_dark']['rgba']==''){$options['c37_dark']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c38_dark']==''){$options['c38_dark']='#434A54';}
            if($options['c39_dark']==''){$options['c39_dark']='#A1A9AE';}
            if($options['c40_dark']==''){$options['c40_dark']='#ED5564';}
            if($options['c41_dark']==''){$options['c41_dark']='#ED5564';}
            if($options['c42_dark']==''){$options['c42_dark']='#A1A9AE';}
            if($options['c43_dark']==''){$options['c43_dark']='#ddd';}
            if($options['c44_dark']==''){$options['c44_dark']='#ED5564';}
            if($options['c45_dark']['rgba']==''){$options['c45_dark']['rgba']='rgba(0,0,0,0.8)';}
            if($options['c46_dark']==''){$options['c46_dark']='#363B43';}
            if($options['c47_dark']==''){$options['c47_dark']='#141D26';}
            
/* General */
            // COLOR 01  Body Background
            $css.='body{background-color:'.$options['c1_dark'].'}'."\n";
            // COLOR 02  Text Color
            $css.='body{color:'.$options['c2_dark']['rgba'].'}'."\n";
            // COLOR 03  Content Background
            $css.='.Body{background-color:'.$options['c3_dark'].'}'."\n";
            // COLOR 04  Section Title Color
            $css.='.SectionTitle,.SectionTitle.Clr1,.TtPornText h1,.textwidget h1,.TtPornText h2,.textwidget h2,.TtPornText h3,.textwidget h3,.TtPornText h4,.textwidget h4,.TtPornText h5,.textwidget h5,.TtPornText h6,.textwidget h6{color:'.$options['c4_dark'].'}'."\n";
            // COLOR 05  Links Color
            $css.='a{color:'.$options['c5_dark'].'}';
            // COLOR 06  Links Color (Hover)
            $css.='a:hover,.tagcloud a:before{color:'.$options['c6_dark'].'}';
            
/* Header */            
            // COLOR 07  Header Background
            $css.='.Header{background-color:'.$options['c7_dark'].'}';
            // COLOR 08  Header Background (Top)
            $css.='.HeaderTop{background-color:'.$options['c8_dark']['rgba'].'}';
            // COLOR 09  Header Background (Bot Header-Alt Menu Bar)
            $css.='.HeaderBot{background-color:'.$options['c9_dark']['rgba'].'}';
                    
/* Menu */
            // COLOR 10  Menu Background
            $css.='.TtMenu,.TtMenu .menu-item-has-children>ul{background-color:'.$options['c10_dark'].'}';
            // COLOR 11  Menu Color
            $css.='.TtMenu,.TtMenu a{color:'.$options['c11_dark']['rgba'].'}';
            // COLOR 12  Menu Icon Color
            $css.='.TtMenu>ul>li:before{color:'.$options['c12_dark'].'}';
            // COLOR 13  Menu Item Background (Hover)
            $css.='.TtMenu li:hover{background-color:'.$options['c13_dark']['rgba'].'}';
            // COLOR 14  Menu Icon Color (Hover)
            $css.='.TtMenu>ul>li:hover:before{color:'.$options['c14_dark'].'}';
            
/* Comments*/
            // COLOR 15  Comment Background
            $css.='.Comment>div{background-color:'.$options['c15_dark'].'}';
            $css.='.Comment>div:after{border-right-color:'.$options['c15_dark'].'!important}';
            // COLOR 16  Comment Border-Color
            $css.='.Comment>div,.Comment figure img{border-color:'.$options['c16_dark'].'}';
            $css.='.Comment>div:before{border-right-color:'.$options['c16_dark'].'}';

/* Borders*/
            // COLOR 17  Border Separation
            $css.='.ListCommts+.RespondTt:before,.TtPornInfo:before,.ListPornInfo.Top:after{background-color:'.$options['c17_dark']['rgba'].'}';
            $css.='.TtBxTp,.ListAlph>li>a,.SwHdBtn:before,.ClpsCn>.ClpsTp{border-color:'.$options['c17_dark']['rgba'].'}';

/*  Form elements (Input/Textarea/etc...) */
            // COLOR 18  Border Color
            $css.='input,textarea,select,.Select label,.ListFilter label{border-color:'.$options['c18_dark']['rgba'].'}';
            // COLOR 19  Border (Focus)
            $css.='input:focus,textarea:focus,select:focus,.Select label:focus{border-color:'.$options['c19_dark'].'}';
            // COLOR 20  Background
            $css.='input,textarea,select,.Select label,.ListFilter label{background-color:'.$options['c20_dark'].'}';
            // COLOR 21  Icons color
            $css.='.Form-Icon input+i,.Form-Icon textarea+i{color:'.$options['c21_dark'].'}';
            // COLOR 22  Icons color (Focus)
            $css.='.Form-Icon input:focus+i,.Form-Icon textarea:focus+i{color:'.$options['c22_dark'].'}';

/* Buttons */
            // COLOR 23  Background Buttons
            $css.='.Button,a.Button,button,input[type="button"],input[type="reset"],input[type="submit"]{background-color:'.$options['c23_dark'].'}';
            // COLOR 24  Background Buttons (Hover)
            $css.='.Button:hover,a.Button:hover,button:hover,input[type="button"]:hover,input[type="reset"]:hover,input[type="submit"]:hover{background-color:'.$options['c24_dark'].'}';
            // COLOR 25  Background Buttons Color
            $css.='.Button,a.Button,button,input[type="button"],input[type="reset"],input[type="submit"]{color:'.$options['c25_dark'].'}';

/* Post Ratings*/
            // COLOR 26  Positive link color
            $css.='.Tt-Votes a.Tt-VoteUp{color:'.$options['c26_dark'].'}';
            // COLOR 27  Negative link color
            $css.='.Tt-Votes a.Tt-VoteDown{color:'.$options['c27_dark'].'}';
            // COLOR 28  Background bar
            $css.='.Tt-Bar>div{background-color:'.$options['c28_dark'].'}';

/* Porn Stars Section */
            // COLOR 29  Background
            $css.='.PornStars{background-color:'.$options['c29_dark']['rgba'].'}';
            // COLOR 30  Title
            $css.='.PornStars .SectionTitle{color:'.$options['c30_dark'].'}';
            
/* External links Section*/
            // COLOR 31  Background
            $css.='.ExternalLnks{background-color:'.$options['c31_dark']['rgba'].'}';
            // COLOR 32  Title
            $css.='.ExternalLnks .SectionTitle{color:'.$options['c32_dark'].'}';

/* Categories Section */
            // COLOR 33  Background
            $css.='.Categories{background-color:'.$options['c33_dark'].'}';
            // COLOR 34  Title
            $css.='.Categories .SectionTitle{color:'.$options['c34_dark'].'}';

/* Footer*/
            // COLOR 35  Footer Background
            $css.='.Footer{background-color:'.$options['c35_dark'].'}';
            // COLOR 36  Footer Background (Top)
            $css.='.FooterTop{background-color:'.$options['c36_dark']['rgba'].'}';
            // COLOR 37  Footer Background (Mid)
            $css.='.FooterMid{background-color:'.$options['c37_dark']['rgba'].'}';
            // COLOR 38  Footer Background (Bot)
            $css.='.FooterBot{background-color:'.$options['c38_dark'].'}';

/* Others */
            // COLOR 39  Background/Color (Header/Menus/Footer/Icons & Other things) Gral. #1
            $css.='.Bgc1,.Bgc1B:Before,.ListExtLnks>li>a,.ListAlph.Top>li>a,.widget_calendar table caption,.error-404 .Search{background-color:'.$options['c39_dark'].'}';
            $css.='.Clr1,.Clr1B:before,.SubsBx button,.Tt-Percent,.TtBxCn button.ClearFilter,.widget_calendar thead th{color:'.$options['c39_dark'].'}';
            $css.='@media all and (max-width: 950px){.TtDwMenu,.TtMenuFt ul{background-color:'.$options['c39_dark'].'}}';
            $css.='@media all and (min-width: 1400px){.ListAlph.Top{background-color:'.$options['c39_dark'].'}}';
            
            // COLOR 40  Background/Color (Hover/Current Links) Gral. #2
            $css.='.TtBxCn .TtBxTp+ul li:hover,.widget_nav_menu div ul li:hover,.Bgc2,.Bgc2B:before,div.wp-pagenavi a:hover,div.wp-pagenavi span.current,.ListExtLnks>li>a:hover,.ListAlph>li.Current>a,.ListAlph>li.Current:hover>a,.Button.Current,#wp-calendar #today,.page-links>a:hover,.page-links>span{background-color:'.$options['c40_dark'].'}';
            $css.='@media all and (max-width: 950px){#TtDwMenu:checked~.TtDwMenu,#TtDwMenu.slvzr-checked~.TtDwMenu{background-color:'.$options['c40_dark'].'}}';
            $css.='.ListFilter label:hover,.ListFilter input:checked+label,.ListFilter input.slvzr-checked+label{border-color:'.$options['c40_dark'].'}';
            $css.='.Clr2,.Clr2B:before,.FooterMid .TtMenu>ul>li:hover:before,.SubsBx button:hover,.ListFilter input:checked+label,.ListFilter input.slvzr-checked+label,.ListFilter label:hover,.TtBxCn button.ClearFilter span,.comment-reply-link:before,.PostInt h1,.Tt-VoteDown,.TtBxCn button.ClearFilter:hover,.cancel-comment-reply a:before,.TtMenuFt li[class*="fa-"]:hover:before{color:'.$options['c40_dark'].'}';

            // COLOR 41  Background/Color (Icons) Gral. #3
            $css.='.SectionTitle[class*="fa-"]:before,.Bgc3,.Bgc3B:before,.Tt-Bar>div,.mCS-default .mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar,.Button.Download,.HdCookie,.page-links>span.page-links-title,.TtPornText h1:after,.textwidget h1:after,.TtPornText h2:after,.textwidget h2:after,.TtPornText h3:after,.textwidget h3:after{background-color:'.$options['c41_dark'].'}';
            $css.='.Post .OutPst:after{border-top-color:'.$options['c41_dark'].'}';
            $css.='.Clr3,.Clr3B:before,a.Tt-Like:before,a.Tt-Like:hover,a.Tt-VoteUp,.CkCnt .Button:before{color:'.$options['c41_dark'].'}';

            // COLOR 42  Background/Color (Other things) Gral. #4
            $css.='.ListAlph>li:hover>a,.Tt-Bar,div.wp-pagenavi a,div.wp-pagenavi span,.page-links>a,.page-links>span,.HDPst{background-color:'.$options['c42_dark'].'}';

            // COLOR 43  Background ScrollBar (Only in Chrome/Safari-Webkit browsers)
            $css.='::-webkit-scrollbar{background-color:'.$options['c43_dark'].'}';

            // COLOR 44  Background ScrollBar-Thumb
            $css.='::-webkit-scrollbar-thumb{background-color:'.$options['c44_dark'].'}';

            // COLOR 45  Post info (Bar)
            $css.='.Post .Info{background-color:'.$options['c45_dark']['rgba'].'}';

            // COLOR 46  Widgets/Post/Content Backgorund
            $css.='.TtBxCn,.ListCate .Cate,.PostInt,.ClpsCn>.ClpsTp.SectionTitle,.ClpsBd>div,.ListPost>li:before,.ListPornStar>li:before,.SiteInfo{background-color:'.$options['c46_dark'].'}';
            $css.='@media all and (min-width: 950px){.TtStyA .Post header{background-color:'.$options['c46_dark'].'}}';

            // COLOR 47  Special Widget
            $css.='.TtBxCn.Dark{background-color:'.$options['c47_dark'].'}';
            
        }elseif($options['color']==3) { // alternative TTCLR-C

            if($options['c1_alternative']==''){$options['c1_alternative']='#111111';}
            if($options['c2_alternative']['rgba']==''){$options['c2_alternative']['rgba']='rgba(255,255,255,0.5)';}
            if($options['c3_alternative']==''){$options['c3_alternative']='#252525';}
            if($options['c4_alternative']==''){$options['c4_alternative']='#fff';}
            if($options['c5_alternative']==''){$options['c5_alternative']='#fff';}
            if($options['c6_alternative']==''){$options['c6_alternative']='#F4C600';}
            if($options['c7_alternative']==''){$options['c7_alternative']='#42435B';}
            if($options['c8_alternative']==''){$options['c8_alternative']='#C4371B';}
            if($options['c9_alternative']['rgba']==''){$options['c9_alternative']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c10_alternative']==''){$options['c10_alternative']='#C4371B';}
            if($options['c11_alternative']==''){$options['c11_alternative']='#fff';}
            if($options['c12_alternative']['rgba']==''){$options['c12_alternative']['rgba']='rgba(255,255,255,0.5)';}
            if($options['c13_alternative']['rgba']==''){$options['c13_alternative']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c14_alternative']==''){$options['c14_alternative']='#F4C600';}
            if($options['c15_alternative']==''){$options['c15_alternative']='#333';}
            if($options['c16_alternative']==''){$options['c16_alternative']='#444';}
            if($options['c17_alternative']['rgba']==''){$options['c17_alternative']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c18_alternative']['rgba']==''){$options['c18_alternative']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c19_alternative']==''){$options['c19_alternative']='#F4C600';}
            if($options['c20_alternative']['rgba']==''){$options['c20_alternative']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c21_alternative']['rgba']==''){$options['c21_alternative']['rgba']='rgba(255,255,255,0.3)';}
            if($options['c22_alternative']==''){$options['c22_alternative']='#F4C600';}
            if($options['c23_alternative']==''){$options['c23_alternative']='#D19600';}
            if($options['c24_alternative']==''){$options['c24_alternative']='#F4C600';}
            if($options['c25_alternative']==''){$options['c25_alternative']='#fff';}
            if($options['c26_alternative']==''){$options['c26_alternative']='#43c130';}
            if($options['c27_alternative']==''){$options['c27_alternative']='#F51824';}
            if($options['c28_alternative']==''){$options['c28_alternative']='#43c130';}
            if($options['c29_alternative']['rgba']==''){$options['c29_alternative']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c30_alternative']==''){$options['c30_alternative']='#fff';}
            if($options['c31_alternative']['rgba']==''){$options['c31_alternative']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c32_alternative']==''){$options['c32_alternative']='#fff';}
            if($options['c33_alternative']==''){$options['c33_alternative']='#252525';}
            if($options['c34_alternative']==''){$options['c34_alternative']='#fff';}
            if($options['c35_alternative']==''){$options['c35_alternative']='#C4371B';}
            if($options['c36_alternative']['rgba']==''){$options['c36_alternative']['rgba']='rgba(0,0,0,0.5)';}
            if($options['c37_alternative']['rgba']==''){$options['c37_alternative']['rgba']='rgba(0,0,0,0.4)';}
            if($options['c38_alternative']['rgba']==''){$options['c38_alternative']['rgba']='rgba(0,0,0,0.2)';}
            if($options['c39_alternative']==''){$options['c39_alternative']='#D19600';}
            if($options['c40_alternative']==''){$options['c40_alternative']='#F4C600';}
            if($options['c41_alternative']==''){$options['c41_alternative']='#04BD9D';}
            if($options['c42_alternative']==''){$options['c42_alternative']='#D19600';}
            if($options['c43_alternative']==''){$options['c43_alternative']='#ddd';}
            if($options['c44_alternative']==''){$options['c44_alternative']='#F4C600';}
            if($options['c45_alternative']['rgba']==''){$options['c45_alternative']['rgba']='rgba(0,0,0,0.7)';}
            if($options['c46_alternative']==''){$options['c46_alternative']='#1E1E1E';}
            if($options['c47_alternative']==''){$options['c47_alternative']='#C4371B';}            
            
/* General */
            // COLOR 01  Body Background
            $css.='body{background-color:'.$options['c1_alternative'].'}'."\n";
            // COLOR 02  Text Color
            $css.='body{color:'.$options['c2_alternative']['rgba'].'}'."\n";
            // COLOR 03  Content Background
            $css.='.Body{background-color:'.$options['c3_alternative'].'}'."\n";
            // COLOR 04  Section Title Color
            $css.='.SectionTitle,.SectionTitle.Clr1,.TtPornText h1,.textwidget h1,.TtPornText h2,.textwidget h2,.TtPornText h3,.textwidget h3,.TtPornText h4,.textwidget h4,.TtPornText h5,.textwidget h5,.TtPornText h6,.textwidget h6{color:'.$options['c4_alternative'].'}'."\n";
            // COLOR 05  Links Color
            $css.='a{color:'.$options['c5_alternative'].'}';
            // COLOR 06  Links Color (Hover)
            $css.='a:hover,.tagcloud a:before{color:'.$options['c6_alternative'].'}';
            
/* Header */            
            // COLOR 07  Header Background
            $css.='.Header{background-color:'.$options['c7_alternative'].'}';
            // COLOR 08  Header Background (Top)
            $css.='.HeaderTop{background-color:'.$options['c8_alternative'].'}';
            // COLOR 09  Header Background (Bot Header-Alt Menu Bar)
            $css.='.HeaderBot{background-color:'.$options['c9_alternative']['rgba'].'}';
                    
/* Menu */
            // COLOR 10  Menu Background
            $css.='.TtMenu,.TtMenu .menu-item-has-children>ul{background-color:'.$options['c10_alternative'].'}';
            // COLOR 11  Menu Color
            $css.='.TtMenu,.TtMenu a{color:'.$options['c11_alternative'].'}';
            // COLOR 12  Menu Icon Color
            $css.='.TtMenu>ul>li:before{color:'.$options['c12_alternative']['rgba'].'}';
            // COLOR 13  Menu Item Background (Hover)
            $css.='.TtMenu li:hover{background-color:'.$options['c13_alternative']['rgba'].'}';
            // COLOR 14  Menu Icon Color (Hover)
            $css.='.TtMenu>ul>li:hover:before{color:'.$options['c14_alternative'].'}';
            
/* Comments*/
            // COLOR 15  Comment Background
            $css.='.Comment>div{background-color:'.$options['c15_alternative'].'}';
            $css.='.Comment>div:after{border-right-color:'.$options['c15_alternative'].'!important}';
            // COLOR 16  Comment Border-Color
            $css.='.Comment>div,.Comment figure img{border-color:'.$options['c16_alternative'].'}';
            $css.='.Comment>div:before{border-right-color:'.$options['c16_alternative'].'}';

/* Borders*/
            // COLOR 17  Border Separation
            $css.='.ListCommts+.RespondTt:before,.TtPornInfo:before,.ListPornInfo.Top:after{background-color:'.$options['c17_alternative']['rgba'].'}';
            $css.='.TtBxTp,.ListAlph>li>a,.SwHdBtn:before,.ClpsCn>.ClpsTp{border-color:'.$options['c17_alternative']['rgba'].'}';

/*  Form elements (Input/Textarea/etc...) */
            // COLOR 18  Border Color
            $css.='input,textarea,select,.Select label,.ListFilter label{border-color:'.$options['c18_alternative']['rgba'].'}';
            // COLOR 19  Border (Focus)
            $css.='input:focus,textarea:focus,select:focus,.Select label:focus{border-color:'.$options['c19_alternative'].'}';
            // COLOR 20  Background
            $css.='input,textarea,select,.Select label,.ListFilter label{background-color:'.$options['c20_alternative']['rgba'].'}';
            // COLOR 21  Icons color
            $css.='.Form-Icon input+i,.Form-Icon textarea+i{color:'.$options['c21_alternative']['rgba'].'}';
            // COLOR 22  Icons color (Focus)
            $css.='.Form-Icon input:focus+i,.Form-Icon textarea:focus+i{color:'.$options['c22_alternative'].'}';

/* Buttons */
            // COLOR 23  Background Buttons
            $css.='.Button,a.Button,button,input[type="button"],input[type="reset"],input[type="submit"]{background-color:'.$options['c23_alternative'].'}';
            // COLOR 24  Background Buttons (Hover)
            $css.='.Button:hover,a.Button:hover,button:hover,input[type="button"]:hover,input[type="reset"]:hover,input[type="submit"]:hover{background-color:'.$options['c24_alternative'].'}';
            // COLOR 25  Background Buttons Color
            $css.='.Button,a.Button,button,input[type="button"],input[type="reset"],input[type="submit"]{color:'.$options['c25_alternative'].'}';

/* Post Ratings*/
            // COLOR 26  Positive link color
            $css.='.Tt-Votes a.Tt-VoteUp{color:'.$options['c26_alternative'].'}';
            // COLOR 27  Negative link color
            $css.='.Tt-Votes a.Tt-VoteDown{color:'.$options['c27_alternative'].'}';
            // COLOR 28  Background bar
            $css.='.Tt-Bar>div{background-color:'.$options['c28_alternative'].'}';

/* Porn Stars Section */
            // COLOR 29  Background
            $css.='.PornStars{background-color:'.$options['c29_alternative']['rgba'].'}';
            // COLOR 30  Title
            $css.='.PornStars .SectionTitle{color:'.$options['c30_alternative'].'}';
            
/* External links Section*/
            // COLOR 31  Background
            $css.='.ExternalLnks{background-color:'.$options['c31_alternative']['rgba'].'}';
            // COLOR 32  Title
            $css.='.ExternalLnks .SectionTitle{color:'.$options['c32_alternative'].'}';

/* Categories Section */
            // COLOR 33  Background
            $css.='.Categories{background-color:'.$options['c33_alternative'].'}';
            // COLOR 34  Title
            $css.='.Categories .SectionTitle{color:'.$options['c34_alternative'].'}';

/* Footer*/
            // COLOR 35  Footer Background
            $css.='.Footer{background-color:'.$options['c35_alternative'].'}';
            // COLOR 36  Footer Background (Top)
            $css.='.FooterTop{background-color:'.$options['c36_alternative']['rgba'].'}';
            // COLOR 37  Footer Background (Mid)
            $css.='.FooterMid{background-color:'.$options['c37_alternative']['rgba'].'}';
            // COLOR 38  Footer Background (Bot)
            $css.='.FooterBot{background-color:'.$options['c38_alternative']['rgba'].'}';

/* Others */
            // COLOR 39  Background/Color (Header/Menus/Footer/Icons & Other things) Gral. #1
            $css.='.Bgc1,.Bgc1B:Before,.ListExtLnks>li>a,.ListAlph.Top>li>a,.widget_calendar table caption,.error-404 .Search{background-color:'.$options['c39_alternative'].'}';
            $css.='.Clr1,.Clr1B:before,.SubsBx button,.Tt-Percent,.TtBxCn button.ClearFilter,.widget_calendar thead th{color:'.$options['c39_alternative'].'}';
            $css.='@media all and (max-width: 950px){.TtDwMenu,.TtMenuFt ul{background-color:'.$options['c39_alternative'].'}}';
            $css.='@media all and (min-width: 1400px){.ListAlph.Top{background-color:'.$options['c39_alternative'].'}}';
            
            // COLOR 40  Background/Color (Hover/Current Links) Gral. #2
            $css.='.TtBxCn .TtBxTp+ul li:hover,.widget_nav_menu div ul li:hover,.Bgc2,.Bgc2B:before,div.wp-pagenavi a:hover,div.wp-pagenavi span.current,.ListExtLnks>li>a:hover,.ListAlph>li.Current>a,.ListAlph>li.Current:hover>a,.Button.Current,#wp-calendar #today,.page-links>a:hover,.page-links>span{background-color:'.$options['c40_alternative'].'}';
            $css.='@media all and (max-width: 950px){#TtDwMenu:checked~.TtDwMenu,#TtDwMenu.slvzr-checked~.TtDwMenu{background-color:'.$options['c40_alternative'].'}}';
            $css.='.ListFilter label:hover,.ListFilter input:checked+label,.ListFilter input.slvzr-checked+label{border-color:'.$options['c40_alternative'].'}';
            $css.='.Clr2,.Clr2B:before,.FooterMid .TtMenu>ul>li:hover:before,.SubsBx button:hover,.ListFilter input:checked+label,.ListFilter input.slvzr-checked+label,.ListFilter label:hover,.TtBxCn button.ClearFilter span,.comment-reply-link:before,.PostInt h1,.Tt-VoteDown,.TtBxCn button.ClearFilter:hover,.cancel-comment-reply a:before,.TtMenuFt li[class*="fa-"]:hover:before{color:'.$options['c40_alternative'].'}';

            // COLOR 41  Background/Color (Icons) Gral. #3
            $css.='.SectionTitle[class*="fa-"]:before,.Bgc3,.Bgc3B:before,.Tt-Bar>div,.mCS-default .mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar,.Button.Download,.HdCookie,.page-links>span.page-links-title,.TtPornText h1:after,.textwidget h1:after,.TtPornText h2:after,.textwidget h2:after,.TtPornText h3:after,.textwidget h3:after{background-color:'.$options['c41_alternative'].'}';
            $css.='.Post .OutPst:after{border-top-color:'.$options['c41_alternative'].'}';
            $css.='.Clr3,.Clr3B:before,a.Tt-Like:before,a.Tt-Like:hover,a.Tt-VoteUp,.CkCnt .Button:before{color:'.$options['c41_alternative'].'}';

            // COLOR 42  Background/Color (Other things) Gral. #4
            $css.='.ListAlph>li:hover>a,.Tt-Bar,div.wp-pagenavi a,div.wp-pagenavi span,.page-links>a,.page-links>span,.HDPst{background-color:'.$options['c42_alternative'].'}';

            // COLOR 43  Background ScrollBar (Only in Chrome/Safari-Webkit browsers)
            $css.='::-webkit-scrollbar{background-color:'.$options['c43_alternative'].'}';

            // COLOR 44  Background ScrollBar-Thumb
            $css.='::-webkit-scrollbar-thumb{background-color:'.$options['c44_alternative'].'}';

            // COLOR 45  Post info (Bar)
            $css.='.Post .Info{background-color:'.$options['c45_alternative']['rgba'].'}';

            // COLOR 46  Widgets/Post/Content Backgorund
            $css.='.TtBxCn,.ListCate .Cate,.PostInt,.ClpsCn>.ClpsTp.SectionTitle,.ClpsBd>div,.ListPost>li:before,.ListPornStar>li:before,.SiteInfo{background-color:'.$options['c46_alternative'].'}';
            $css.='@media all and (min-width: 950px){.TtStyA .Post header{background-color:'.$options['c46_alternative'].'}}';

            // COLOR 47  Special Widget
            $css.='.TtBxCn.Dark{background-color:'.$options['c47_alternative'].'}';
            
        }

        if( $wp_filesystem ) {
            $wp_filesystem->put_contents(
                $filename,
                $css,
                FS_CHMOD_FILE // predefined mode settings for WP files
            );
        }
    }

    if ( ! function_exists( 'redux_license' ) ) {
        function redux_license( $field, $value ) {
            if(get_option('trlicense')!=''){
                echo '<p><input class="regular-text" name="tr_activation_text" type="password" value="'.get_option('trlicense').'" placeholder="'.__( 'Enter your license', TR_THEMENAMEOPTIONS ).'"><button name="tr_activation_bt" type="button" class="button button-primary" data-txt="'.__('Check', TR_THEMENAMEOPTIONS).'">'.__('Check', TR_THEMENAMEOPTIONS).'</button></p><span id="tr_activation">'.__('License activated properly.', TR_THEMENAMEOPTIONS).'</span>';            
            }else{
                echo '<p><input class="regular-text" name="tr_activation_text" type="password" placeholder="'.__( 'Enter your license', TR_THEMENAMEOPTIONS ).'"><button name="tr_activation_bt" type="button" class="button button-primary" data-txt="'.__('Check', TR_THEMENAMEOPTIONS).'">'.__('Check', TR_THEMENAMEOPTIONS).'</button></p><span id="tr_activation"></span>';
            }
        }
    }

    function tr_remove_demo() {

        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
            remove_filter( 'plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2 );

            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
    }
}

    if(!function_exists('tr_redirect_validate')){
        die();
    }