<?php

class WP_Widget_Trmenu extends WP_Widget {

	public function __construct() {
		$widget_ops = array('classname' => 'widget_trmenu', 'description' => __( "Widget for other style menus", TR_THEMENAMEOPTIONS) );
		parent::__construct('tr-menu', __('TR Menu', TR_THEMENAMEOPTIONS), $widget_ops);
		$this->alt_option_name = 'widget_trmenu';
	}

	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$tr_show = $instance['tr_show'];        
		$nav_menu = ! empty( $instance['nav_menu'] ) ? wp_get_nav_menu_object( $instance['nav_menu'] ) : false;
        $nav_menu_args = array('container' => false, 'items_wrap' => '%3$s', 'fallback_cb' => '', 'menu' => $nav_menu);
?>
        <!--<Menu>-->
        <div class="TtBxCn">
            <nav class="TtMenu">
                <ul>
                    <?php wp_nav_menu( apply_filters( 'widget_nav_menu_args', $nav_menu_args, $nav_menu, $args, $instance ) ) ?>
                </ul>
                <?php if($tr_show==0){ ?>
                <div class="Search">
                    <form method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>">
                        <input name="s" type="text" placeholder="<?php _e('Search...', TR_THEMENAME); ?>">
                        <button type="submit"><span class="fa-search"></span></button>
                    </form>
                </div>
                <?php } ?>
            </nav>
        </div>
        <!--</Menu>-->
<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		if ( ! empty( $new_instance['nav_menu'] ) ) {
			$instance['nav_menu'] = (int) $new_instance['nav_menu'];
		}
		$instance['tr_show'] = empty($new_instance['tr_show']) ? 1 : 0 ;
		return $instance;
	}

	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$nav_menu = isset( $instance['nav_menu'] ) ? $instance['nav_menu'] : '';
		$tr_show = isset( $instance['tr_show'] ) ? (bool) $instance['tr_show'] : false;
		$menus = wp_get_nav_menus();
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>
		
        <p>
            <label for="<?php echo $this->get_field_id( 'nav_menu' ); ?>"><?php _e( 'Select Menu:' ); ?></label>
            <select id="<?php echo $this->get_field_id( 'nav_menu' ); ?>" name="<?php echo $this->get_field_name( 'nav_menu' ); ?>">
                <option value="0"><?php _e( '&mdash; Select &mdash;' ); ?></option>
                <?php foreach ( $menus as $menu ) : ?>
                    <option value="<?php echo esc_attr( $menu->term_id ); ?>" <?php selected( $nav_menu, $menu->term_id ); ?>>
                        <?php echo esc_html( $menu->name ); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </p>
		
		<p><input class="checkbox" type="checkbox"<?php checked( '', $tr_show ); ?> id="<?php echo $this->get_field_id( 'tr_show' ); ?>" name="<?php echo $this->get_field_name( 'tr_show' ); ?>" value="1" />
		<label for="<?php echo $this->get_field_id( 'tr_show' ); ?>"><?php _e( 'Show search form?', TR_THEMENAMEOPTIONS ); ?></label></p>
<?php
	}
}